package com.ibm.able.examples;

//====================================================================
//
// Licensed Materials - Property of IBM
//
// "Restricted Materials of IBM"
//
// Product: com.ibm.able.examples
//
// (C) Copyright IBM Corp. 2000 All Rights Reserved.
//
// US Government Users Restricted Rights - Use, duplication or
// disclosure restricted by GSA ADP Schedule Contract with 
// IBM Corp.
//
//                                                                        
//                             DISCLAIMER                                 
//                             ----------                                 
//                                                                        
// This material contains programming source code for your consideration. 
// These examples have not been thoroughly tested under all conditions.   
// IBM, therefore, cannot guarantee or imply reliability, serviceability, 
// performance or function of these programs.  All programs contained     
// herein are provided to you "AS IS".  THE IMPLIED WARRANTIES OF         
// MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE EXPRESSLY     
// DISCLAIMED.                                                            
//                                                                                                                                               
//====================================================================

//====================================================================
// Imports
//====================================================================
import java.rmi.*;
import java.io.*;
import com.ibm.able.*;


/**
 *  This class is a wrapper for custom algorithms.  Its intended to
 *  allow the developer to implement the interfaces needed to incorporate
 *  an algorithm in Able with minimal changes to the original class.
 *  To use this class, substitute your own package in place of 
 *  com\ibm\able\examples, and globally change the string <i>BeanWrapper</i>
 *  with the name of your algorithm's class in these class and html files.
 *
 * @version  $Revision: 1.2 $, $Date: 2000/09/28 13:17:26 $
 *
 * @author   Joe Bigus
 */
 public class AbleBeanWrapper extends AbleObject implements Serializable {


  //==================================================================
  //
  // Class Variables
  //
  //==================================================================

  /**
   *  Required for serializable.  When a bean is read from a serialized
   *  form, this variable can be used to determine its version id.
   *  Change this value when changes are made to this class that make
   *  previous versions incompatible.
   */
   static final long    serialVersionUID = 1999100100000000001L;
  
  /** 
   *  Provide a copyright statement for your package to satisfy
   *  intellectual property requirements.  Declare it in this
   *  class and reference it from others.
   */
   public static final String  Copyright = "(C) Copyright IBM Corporation 1999, 2000.";
   
  //==================================================================
  //
  // Instance Variables
  //
  //==================================================================

  /**
   *  BeanWrapper is the algorithm that processes the data.
   */
   //private BeanWrapper myBeanWrapper = null;

  //==================================================================
  //
  // Constructors
  //
  //==================================================================
  /**
   * Construct an AbleBeanWrapper.
   *
   * @return    AbleBeanWrapper.
   */
   public AbleBeanWrapper() throws RemoteException {
       this("AbleBeanWrapper");
   }


  /**
   * Construct an AbleBeanWrapper with specified name.
   * This method may include a call to the init method.
   * Construct the underlying object
   *
   * @param     aName
   *            A String object specifying the object name
   *            <p>
   * @return    AbleBeanWrapper.
   */
   public AbleBeanWrapper(String aName) throws RemoteException {
       super(aName) ;
       // myBeanWrapper = new BeanWrapper();
       // init();
   }


  //------------------------------------------------------------------
  // Processing methods
  //------------------------------------------------------------------
  /**
   * Call any methods in BeanWrapper to initialize the algorithm.
   * For Able:
   * <ol>
   *    <li>Allocate input and output buffers if data buffers will be used
   *    <li>Set processing options for timer events and sleep interval
   *    <li>Set AbleEvent processing options
   *    <li>
   *</ol>
   *
   */
   public void init() throws RemoteException {
       /*=======================================================
         Initialize the BeanWrapper with methods you've provided. */
         //myBeanWrapper.init1();
         //myBeanWrapper.init2();
         //myBeanWrapper.setSomeProperty("new");
       /*======================================================*/
       

       /*-------------------------------------------------------
         Are you using data buffers?   
         If so, allocate the AbleObject input and output buffers here,  
         select the array types (String, double, etc), and enable
         processing. */
         //inputBuffer = new String[1];  // inherited from AbleObject
         //outputBuffer = new String[1]; // inherited from AbleObject
         //setDataFlowEnabled(false);
       /* -----------------------------------------------------*/

       /*-------------------------------------------------------
         Are you using timer events?    
         If so, set the interval time in milliseconds and enable 
         processing. */
         //setSleepTime(0);
         //setTimerEventProcessingEnabled(false);
       /*------------------------------------------------------*/

       /*-------------------------------------------------------
         Are you using Able events?    
         If so, set the processing and posting options as desired. */ 
         //setAbleEventProcessingEnabled(Able.ProcessingDisabled_PostingDisabled);
       /*------------------------------------------------------*/

       /* Show we are ready to process */
       super.init(); 
   }

  /**
   *  Reset the bean to a known initialized state.
   *  Fire a global property change event.
   *
   */
   public void reset() throws RemoteException {
       /*=======================================================
         Reset BeanWrapper values with methods you've provided. 
         You may wish to call the same methods called in init,
         or you may wish to call init directly.*/
         //myBeanWrapper.reset();
         //myBeanWrapper.setSomeProperty("reset");
         //init();
       /*======================================================*/
       
       /*-------------------------------------------------------
         If you didn't call this bean's init method, you may wish 
         to inform listeners that properties have changed. */
         // firePropertyChange(AbleProperty.UpdateProperties, null, null);
       /*------------------------------------------------------*/
      
   }


  /**
   * Perform the bean processing function for data buffers.
   *
   * @exception  RemoteException 
   */
   public void process() throws RemoteException {
       /*------------------------------------------------------
         Are you using data buffers?   
         If so, */
       /*1. get the data from the input buffer: */
         //processBufferConnections();   
       /*======================================================*/
       /*2. process it, and put it in the outputbuffer:
           a. If you have lots of logic to be handled inside your algorithm: */
         //outputBuffer = myBeanWrapper.process(inputBuffer); 
       /*  b. If you just want to update a property or two: */
         //Object in = getInputBuffer(0);  // or set values from buffer directly
         //if (in != null) { myBeanWrapper.setSomeProperty((String)in);
         //                  setOutputBuffer(0,(String)in);}
       /*======================================================*/
       /*3. tell any AbleEventListeners that we changed */
         //dataChanged(this);   
       /* -----------------------------------------------------*/

   }


  /**
   * Perform the bean processing function to do when the timer interval expires.
   *
   * @exception  RemoteException 
   */
   public void processTimerEvent() throws RemoteException {
       /*-------------------------------------------------------
         Are you using timer events?    
         Either implement process and call it from this method,
         or use process as a template to follow but provide the
         additional calls to the BeanWrapper as you require. */
         //process();   
       /* -----------------------------------------------------*/

   }
   
  /**
   *  Process an AbleEvent sent by another Able bean.
   *  This is primarily for remote agent use.
   *
   */
   public void handleAbleEvent(AbleEvent theEvent) {
       /*-------------------------------------------------------
         Are you using Able events?                            */   
       //Object theObject = theEvent.getGenSource();      
       /*------------------------------------------------------*/
   }


  //------------------------------------------------------------------
  // Get/Set methods for accessing class member values in BeanWrapper
  //------------------------------------------------------------------
  
  /**
   *   Set the value for some String property in BeanWrapper, and fire a 
   *   propertyChange event to notify any propertyChange listeners.
   */
   public void setSomeProperty(String newValue) throws RemoteException {
       //String oldValue = myBeanWrapper.getSomeProperty();
       //myBeanWrapper.setSomeProperty(newValue);
       //firePropertyChange("someProperty", oldValue, newValue);
   }

  /**
   *   Get the value for some String property from the BeanWrapper
   */
   public String getSomeProperty() { 
       return null; //myBeanWrapper.getSomeProperty(); 
   }
  
  //------------------------------------------------------------------
  // Miscellaneous methods 
  //------------------------------------------------------------------
  
  /**
   * Determine the copyright of this class.
   *
   * @return    A String containing this class's copyright statement.
   *            <p>
   */
   public static String Copyright() {
       return AbleBeanWrapper.Copyright;
   }
  

}
