package com.ibm.able.examples.ablebean;

//====================================================================
//
// Licensed Materials - Property of IBM
//
// "Restricted Materials of IBM"
//
// Product: com.ibm.able.examples.ablebean
//
// (C) Copyright IBM Corp. 2000 All Rights Reserved.
//
// US Government Users Restricted Rights - Use, duplication or
// disclosure restricted by GSA ADP Schedule Contract with 
// IBM Corp.
//
//                                                                        
//                             DISCLAIMER                                 
//                             ----------                                 
//                                                                        
// This material contains programming source code for your consideration. 
// These examples have not been thoroughly tested under all conditions.   
// IBM, therefore, cannot guarantee or imply reliability, serviceability, 
// performance or function of these programs.  All programs contained     
// herein are provided to you "AS IS".  THE IMPLIED WARRANTIES OF         
// MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE EXPRESSLY     
// DISCLAIMED.                                                            
//                                                                                                                                               
//====================================================================

//====================================================================
// Imports
//====================================================================
import java.rmi.*;
import java.beans.*;
import com.ibm.able.*;
import com.ibm.able.beans.*;
import com.ibm.able.agents.*;
// import com.ibm.able.examples.ablebean.*;   // use if running in default package
import com.ibm.able.examples.ableagent.*;

/**
 * This class provides the application for the Simple Able Bean.
 *
 * @version  $Revision: 1.3 $, $Date: 2000/08/10 20:51:35 $
 *
 * @author   Joe Bigus
 */
public class SimpleAbleApp implements AbleEventListener, PropertyChangeListener {

    //-----------------------------------------------------------------
    // Member variables
    //-----------------------------------------------------------------
    private SimpleAbleBean  myBean = null;
    private SimpleAbleAgent myAgent= null ;

    //-----------------------------------------------------------------
    // Constructors
    //-----------------------------------------------------------------
    private SimpleAbleApp() {
    }


    //-----------------------------------------------------------------
	// Main method
    //-----------------------------------------------------------------
    public static void main(String[] args) {
      SimpleAbleApp test = new SimpleAbleApp() ;
      test.test() ;
    }


    //-----------------------------------------------------------------
	// Methods
    //-----------------------------------------------------------------
    private void test() {
        System.out.println("Starting test") ;

        try {
           myBean = new SimpleAbleBean("bean1") ;
           myAgent = new SimpleAbleAgent("agent") ;   // calls super.init(), starts auto thread
           myAgent.addAbleEventListener(this) ;  // catch dataChanged events

           AbleBufferConnection con = new AbleBufferConnection(myAgent, myBean) ;

           String[] outBuf1 = (String[])myAgent.getOutputBuffer() ;
           System.out.println("initial Agent output Buffer = " + displayBuffer(outBuf1)) ;

           String[] outBuf2 = (String[])myBean.getOutputBuffer() ;
           System.out.println("initial Bean output Buffer = " + displayBuffer(outBuf2)) ;

           System.out.println("Let agent autonomous thread drive processing from this point ") ; 
           delay(30) ; // wait 30 seconds
        } catch (RemoteException e) {
           System.out.println("Error: " + e.toString());
        }
        System.out.println("Done!");
    }
    

   /**
    *   Convert an array of objects to a string delimited by
    *   a blank and a newline.
    */
    protected String displayBuffer(Object[] buf) {
        StringBuffer buffer = new StringBuffer("Buffer: ") ;
        for (int i=0 ; i < buf.length ; i++) {
            buffer.append(buf[i] + " " ) ;
        }
        buffer.append("\n");
        return buffer.toString();
    }

   /**
    *   Display changes when agent modifies its output buffer
    */
    public void handleAbleEvent(AbleEvent e) {
        if (e.getId() == AbleEvent.EOF) {
            System.out.println("received AbleEvent " + e) ;
        } else if (e.getId() == AbleEvent.DATACHANGED) {
            System.out.println("received DataChanged AbleEvent ") ;
            try {
                // show current output buffer of agent and bean
                String[] outBuf1 = (String[])myAgent.getOutputBuffer() ;
                System.out.println("Agent output Buffer = " + displayBuffer(outBuf1)) ;
                String[] outBuf2 = (String[])myBean.getOutputBuffer() ;
                System.out.println("Bean output Buffer = " + displayBuffer(outBuf2)) ;

                myBean.process() ;    // now process the bean (move input to output)
                System.out.println("Calling myBean.process() " ) ;
                outBuf2 = (String[])myBean.getOutputBuffer() ;
                System.out.println("Bean output Buffer = " + displayBuffer(outBuf2)) ;
            } catch (RemoteException exc) {} 
        }
    }

   /**
    *   Process an Able event.
    */
    public void processAbleEvent(AbleEvent e) {
        System.out.println("received AbleEvent " + e) ;
        handleAbleEvent(e) ; // handle all events synchronously !!!
    }

   /**
    *   Wait a number of seconds.
    */
    private void delay(int sec) {
        try {
            System.out.println("Test case pause for " + sec + " seconds");
            Thread.sleep(sec * 1000) ;
        } catch (Exception e) { }
    }

   /**
    *   Handle a property change event.
    */
    public void propertyChange(PropertyChangeEvent e) {
        System.out.println("Test program received property change event from " + e.getSource() +
                      e.getPropertyName() + " changed from " + e.getOldValue() + " to " + e.getNewValue());

    }

    /**
     * Determine the copyright of this class.
     *
     * @return    A String containing this class's copyright statement.
     *            <p>
     */
    public static String Copyright() {
      return Able.Copyright;
    }


}
