package com.ibm.able.examples.ablebean;

//====================================================================
//
// Licensed Materials - Property of IBM
//
// "Restricted Materials of IBM"
//
// Product: com.ibm.able.examples.ablebean
//
// (C) Copyright IBM Corp. 2000 All Rights Reserved.
//
// US Government Users Restricted Rights - Use, duplication or
// disclosure restricted by GSA ADP Schedule Contract with 
// IBM Corp.
//
//                                                                        
//                             DISCLAIMER                                 
//                             ----------                                 
//                                                                        
// This material contains programming source code for your consideration. 
// These examples have not been thoroughly tested under all conditions.   
// IBM, therefore, cannot guarantee or imply reliability, serviceability, 
// performance or function of these programs.  All programs contained     
// herein are provided to you "AS IS".  THE IMPLIED WARRANTIES OF         
// MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE EXPRESSLY     
// DISCLAIMED.                                                            
//                                                                                                                                               
//====================================================================

//====================================================================
// Imports
//====================================================================
import java.rmi.*;
import java.io.*;
import com.ibm.able.*;


/**
 *  This class is an example of a simple AbleBean created by extending 
 *  AbleObject.
 *
 *  It copies the value of the inputBuffer to the outputBuffer
 *  If no input connection exists, it will copy the value of the 
 *  simpleBeanColor property to the output buffer.
 *
 * @version  $Revision: 1.7 $, $Date: 2000/08/30 22:25:19 $
 *
 * @author   Joe Bigus
 */
public class SimpleAbleBean extends AbleObject implements Serializable {


  //==================================================================
  //
  // Class Variables
  //
  //==================================================================

  // define any class variables here
  static final long    serialVersionUID = 1999100100000000001L;
  public final static String DefaultBeanColor = "magenta";
  
  //==================================================================
  //
  // Instance Variables
  //
  //==================================================================

  // define any bean-specific instance variables here
   private String simpleBeanColor ;

  //==================================================================
  //
  // Constructors
  //
  //==================================================================
  /**
   * Construct a simple AbleBean
   *
   * @return    SimpleAbleBean.
   */
  public SimpleAbleBean() throws RemoteException {
       this("SimpleBean");
  }


  /**
   * Construct a simple AbleBean with specified name.
   *
   * @param     aName
   *            A String object specifying the object name
   *            <p>
   * @return    SimpleAbleBean.
   */
  public SimpleAbleBean(String aName) throws RemoteException {
       super(aName) ;
       init();
  }


  //------------------------------------------------------------------
  // Processing methods
  //------------------------------------------------------------------
  /**
   * Initialize the bean to a known initialized state.
   *
   */
  public void init() throws RemoteException {
       // need to allocate the input and output buffers here (if used)
       inputBuffer = new String[1] ;
       outputBuffer = new String[1] ;
       simpleBeanColor = DefaultBeanColor ;

       // No timer processing, and no asynch events, just dataflow
       setDataFlowEnabled(true) ;
       setSleepTime(0);
       setTimerEventProcessingEnabled(false);
       setAbleEventProcessingEnabled(Able.ProcessingDisabled_PostingDisabled);
       // Note: we don't create an event queue thread

       setState(AbleState.Active); // show we are ready to process
  }

  /**
   *  Reset the bean to a known initialized state.
   *  Fire a global property change event.
   *
   */
  public void reset() throws RemoteException {
      init() ; // re-allocate the input buffers 
      firePropertyChange(AbleProperty.UpdateProperties, null, null);
      
      // or, to change only bean properties:
      // setSimpleBeanColor(DefaultBeanColor);
  }


  /**
   * Perform the standard processing function performed by this bean.
   * This typically takes data from the inputBuffer, processes it,
   * and places it in the output buffer.
   *
   * @exception AbleException
   *            either RemoteException or process error
   */
  public void process() throws RemoteException {
         processBufferConnections() ;   // move data into inputBuffer (if any)

         // perform the main processing here
         Object in = getInputBuffer(0) ;  // see if there is data in the input buffer
         if (in != null) {
           simpleBeanColor = (String)getInputBuffer(0) ; // copy to the color parameter
         }
         // Note: we either process data in the input buffer
         //       or use other data member values as inputs

         // assign output data to the outputBuffer here
         setOutputBuffer(0, simpleBeanColor) ;

         dataChanged(this) ;  // tell any AbleEventListeners that we changed
  }

  /**
  *   Set the color attribute
  *   Also fire a propertyChange event to notify any propertyChange listeners
  */
  public void setSimpleBeanColor(String newBeanColor) throws RemoteException {
       String oldBeanColor = simpleBeanColor;
       simpleBeanColor = newBeanColor ;
       firePropertyChange("simpleBeanColor", oldBeanColor, newBeanColor);
  }

  /**
  *   Get the color attribute
  */
  public String getSimpleBeanColor() { return simpleBeanColor; }
  
    /**
     * Determine the copyright of this class.
     *
     * @return    A String containing this class's copyright statement.
     *            <p>
     */
    public static String Copyright() {
      return Able.Copyright;
    }
  

}
